import { createBrowserRouter } from 'react-router-dom';
import { default as default_2 } from 'react';
import { DependencyList } from 'react';
import { ErrorBoundaryProps } from 'react-error-boundary';
import { MutableRefObject } from 'react';
import { NavLinkProps } from 'react-router-dom';
import { PropsWithChildren } from 'react';
import { UseFloatingOptions } from '@floating-ui/react';

/**
 * Component of an app item in apps menu.
 */
export declare function AppItem({ className, children, ...props }: default_2.HTMLAttributes<HTMLAnchorElement>): default_2.JSX.Element;

/**
 * Main Kernel UI application.
 */
export declare function Application({ errorElement, children }: default_2.PropsWithChildren<{
    errorElement?: default_2.ReactNode;
}>): default_2.JSX.Element;

/**
 * Application error component.
 */
export declare function ApplicationError({ children }: {
    children?: (error: Error) => default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * Error boundary component for the application.
 */
export declare class ApplicationErrorBoundary extends default_2.Component<default_2.PropsWithChildren<{
    errorElement: default_2.ReactNode;
}>, {
    error: Error;
}> {
    static getDerivedStateFromError(error: Error): {
        error: Error;
    };
    render(): string | number | boolean | Iterable<default_2.ReactNode> | default_2.JSX.Element;
}

/**
 * Component of an app link in apps menu.
 */
export declare function AppLink({ className, children, ...props }: NavLinkProps & default_2.HTMLAttributes<HTMLAnchorElement>): default_2.JSX.Element;

/**
 * Main apps menu component.
 */
export declare function AppsMenu({ className, children, ...props }: default_2.HTMLAttributes<HTMLDivElement>): default_2.JSX.Element;

/**
 * Easy async component with fallback and fulfilled children render.
 * @param promise The promise.
 * @param children Renderer function of the children, takes promised data as argument.
 * @param fallback Content shown when the promise is not fulfilled yet.
 * @constructor
 */
export declare function Async<T>({ promise, fallback, children }: {
    promise: Promisable<T> | PromiseFn<T>;
    children: (async: T) => default_2.ReactElement;
    fallback?: default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * An async page to render.
 */
export declare function AsyncPage<T>({ page, getData, render }: {
    /**
     * The page number to show.
     */
    page: number;
    /**
     * Get data for the given page.
     * @param page The page for which to get data.
     */
    getData: (page: number) => Promise<T>;
    /**
     * Render the page with its retrieved data.
     * @param data Data of the page to show.
     * @param page The page to show.
     */
    render: (data: T, page: number) => default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * Asynchronous paginated content component.
 */
export declare function AsyncPaginate<T>({ count, getData, children }: {
    /**
     * Get pages count.
     */
    count: () => Promise<number>;
    /**
     * Get data for the given page.
     * @param page The page for which to get data.
     */
    getData: (page: number) => Promise<T>;
    /**
     * Show the current page with its retrieved data.
     * @param data Data of the page to show.
     * @param page The page to show.
     */
    children: (data: T, page: number) => default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * Asynchronous data state.
 */
declare interface AsyncState<T> {
    /**
     * Determine if we are waiting for the promise result or not.
     */
    pending: boolean;
    /**
     * The promise which is retrieved (or has retrieved) data.
     */
    promise: Promisable<T>;
    /**
     * Error thrown by the promise.
     */
    error: Error;
    /**
     * The promise result.
     */
    data: T;
}

/**
 * Paginated content component.
 */
export declare function AutoPaginate({ count, children }: {
    /**
     * Pages count.
     */
    count: number;
    /**
     * Show the given page.
     * @param page The page to show.
     */
    children: (page: number) => default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * Wait for the promise to be fulfilled to render the children.
 * @param async The async state.
 * @param children Renderer function of the children, takes promised data as argument.
 * @param fallback Content shown when the promise is not fulfilled yet.
 * @constructor
 */
export declare function Await<T>({ async, children, fallback }: {
    async: AsyncState<T>;
    children: (async: T) => default_2.ReactElement;
    fallback?: default_2.ReactElement;
}): default_2.JSX.Element;

/**
 * Content box generic component.
 */
export declare function Box({ children, className, ...props }: PropsWithChildren<default_2.HTMLAttributes<HTMLDivElement>>): default_2.ReactElement;

export declare function Buttons({ placement, children }: default_2.PropsWithChildren<{
    placement?: "right" | "left" | "center";
}>): default_2.JSX.Element;

/**
 * Calendar component.
 */
export declare function Calendar({ date, onDateSelected, locale, className, ...tableProps }: {
    date: Date;
    onDateSelected: (date: Date) => void;
    locale?: string;
} & default_2.TableHTMLAttributes<HTMLTableElement>): default_2.ReactElement;

/**
 * A callable curtain function with typed parameters.
 */
export declare type CallableCurtain<F extends CallableCurtainElement> = (...args: Parameters<F>) => CurtainUuidType;

/**
 * Callable curtain function generator.
 * @param curtains The curtains context state.
 * @param curtainElement The curtain element to open when called.
 */
export declare function callableCurtain<F extends CallableCurtainElement>(curtains: CurtainsContextState, curtainElement: default_2.ReactNode | F): CallableCurtain<F>;

/**
 * A generic callable curtain element.
 */
export declare type CallableCurtainElement = (...args: any) => default_2.ReactNode;

/**
 * Content card component.
 */
export declare function Card({ children, className, ...props }: PropsWithChildren<default_2.HTMLAttributes<HTMLDivElement>>): default_2.ReactElement;

export declare function Checkbox({ children, className, type, ...inputProps }: default_2.PropsWithChildren<default_2.InputHTMLAttributes<HTMLInputElement>>): default_2.ReactElement;

/**
 * Merge multiple class names to one full class name.
 * @param className Class names.
 */
export declare function classes(...className: (string | null | undefined | false)[]): string;

/**
 * The function that closes a curtain.
 */
export declare type CloseCurtainFunction = (uuid: CurtainUuidType) => void;

/**
 * Type of notification close function.
 */
export declare type CloseNotificationFunction = (uuid: NotificationUuid) => void;

/**
 * Create Kernel context.
 * @param defaultValue Kernel context default value.
 */
export declare function createKernelContext<T>(defaultValue: T): KernelContext<T>;

/**
 * Current curtain data and functions.
 */
export declare interface CurtainContextState {
    /**
     * Curtain UUID.
     */
    uuid: CurtainUuidType;
    /**
     * Close the curtain.
     */
    close: () => void;
    /**
     * True if the curtain is closed (while transitioning out).
     */
    closed: boolean;
}

/**
 * Interface of curtains state.
 */
export declare interface CurtainsContextState {
    /**
     * Open a new curtain.
     * @param content The curtain content.
     * @return UUID of the curtain.
     */
    open: OpenCurtainFunction;
    /**
     * Close the given curtain.
     * @param uuid UUID of the curtain to close.
     */
    close: CloseCurtainFunction;
    /**
     * Check if the given curtain is closed or not.
     * @param uuid UUID of the curtain to check.
     */
    isClosed: IsCurtainClosedFunction;
}

/**
 * Page curtains provider.
 */
export declare function CurtainsProvider({ children }: default_2.PropsWithChildren<{}>): default_2.JSX.Element;

/**
 * Curtain UUID type.
 */
export declare type CurtainUuidType = string;

/**
 * Custom validation rule in a form.
 */
export declare function CustomValidationRule({ valid, errorMessage }: {
    valid: boolean;
    errorMessage: string;
}): default_2.JSX.Element;

/**
 * Datepicker component.
 */
export declare function Datepicker({ date, onDateSelected, locale, className, ...divProps }: {
    date: Date;
    onDateSelected: (date: Date) => void;
    locale?: string;
} & default_2.HTMLAttributes<HTMLDivElement>): default_2.ReactElement;

/**
 * A form input for a date with a datepicker.
 */
export declare function DatepickerInput({ children, className, value, onChange, onKeyUp, onBlur, type, placeholder, ...props }: default_2.PropsWithChildren<Modify<default_2.InputHTMLAttributes<HTMLInputElement>, {
    /**
     * The current date value.
     */
    value?: Date | null;
    /**
     * Called when picked date is changed.
     * @param newDate The new date.
     */
    onChange: (newDate: Date) => void;
    type?: never;
    placeholder?: never;
}>>): default_2.ReactElement;

/**
 * Type of notification emitter function.
 */
export declare type EmitNotificationFunction = (content: default_2.ReactNode) => void;

/**
 * A component to show something floating next to an element.
 */
export declare const Float: default_2.ForwardRefExoticComponent<FloatProperties & default_2.RefAttributes<unknown>>;

/**
 * Type of the element on which the floating element is based.
 */
export declare type FloatChild = (default_2.ReactElement & default_2.ClassAttributes<HTMLElement>) | Managed<(default_2.ReactElement & default_2.ClassAttributes<HTMLElement>)>;

/**
 * Allowed floating modes.
 */
export declare type FloatingMode = "always" | "click" | "hover" | "focus" | "managed";

/**
 * Properties of the Float component.
 */
export declare interface FloatProperties {
    children: FloatChild;
    content?: default_2.ReactNode | Managed<default_2.ReactNode>;
    className?: string;
    mode?: FloatingMode;
    dismissible?: boolean;
    role?: FloatRole;
    floatingOptions?: UseFloatingOptions;
}

/**
 * Role of a floating element.
 */
export declare type FloatRole = "tooltip" | "dialog" | "alertdialog" | "menu" | "listbox" | "grid" | "tree" | "select" | "label" | "combobox";

export declare function formatDate(date: Date): string;

export declare function formatTime(date: Date): string;

export declare function GenericLoader({ children }: default_2.PropsWithChildren<{}>): default_2.JSX.Element;

/**
 * Main global state class.
 */
export declare class GlobalState<S, R extends GlobalStateReducers<S>> {
    protected defaultValue: S;
    protected reducers: R;
    /**
     * Global state context.
     * @protected
     */
    protected context: default_2.Context<S>;
    /**
     * State update system, used in the reducers class.
     * @protected
     */
    protected stateUpdater: default_2.Dispatch<S>;
    /**
     * Create a new global state.
     * @param defaultValue The default value of the global state.
     * @param reducers Reducers class.
     */
    constructor(defaultValue: S, reducers: R);
    /**
     * Get the context for the global state.
     */
    getContext(): default_2.Context<S>;
    /**
     * Get the default value of the global state.
     */
    getDefaultValue(): S;
    /**
     * Assign the state update system, used in the reducers class.
     * @param updater State update system instance.
     */
    setStateUpdater(updater: default_2.Dispatch<S>): void;
    /**
     * Get the configured state reducers class for the current state.
     * @param state The state on which the reducers should apply.
     */
    getStateReducers(state: S): R;
}

/**
 * Global state Provider component
 * @constructor
 */
export declare function GlobalStateProvider<S, R extends GlobalStateReducers<S>>({ globalState, children }: default_2.PropsWithChildren<{
    /**
     * Global state for which to get the global state Provider.
     */
    globalState: GlobalState<S, R>;
}>): default_2.JSX.Element;

/**
 * Global state modifiers functions.
 */
export declare class GlobalStateReducers<S> {
    /**
     * The current state (readonly).
     * @protected
     */
    protected state: Readonly<S>;
    /**
     * State update system.
     * @private
     */
    private stateUpdater;
    /**
     * Assign changes to the current state.
     * @param stateUpdate Changes to apply to the current state.
     */
    setState(stateUpdate: Partial<S>): void;
}

/**
 * The function that checks if a curtain is closed (while transitioning out) or not.
 */
export declare type IsCurtainClosedFunction = (uuid: CurtainUuidType) => boolean;

/**
 * Type of notification closed state function.
 */
export declare type IsNotificationClosedFunction = (uuid: NotificationUuid) => boolean;

/**
 * Main Kernel UI app component which initializes everything.
 */
export declare function Kernel({ header, footer, router }: {
    header?: default_2.ReactNode;
    footer?: default_2.ReactNode;
    router: ReturnType<typeof createBrowserRouter>;
}): default_2.JSX.Element;

/**
 * Kernel context definition object.
 */
export declare interface KernelContext<T> {
    /**
     * Kernel context UUID.
     */
    uuid: string;
    /**
     * Kernel context default value.
     */
    defaultValue: T;
}

/**
 * Kernel context dispatcher function type.
 */
export declare type KernelContextDispatcher<ValueType = any> = (value: ValueType) => void;

/**
 * Kernel contexts type.
 */
export declare type KernelContexts = Record<string, any>;

/**
 * Kernel context setter function type.
 */
export declare type KernelContextSetter<IdentifierType extends string | symbol | number = string, ValueType = any> = (identifier: IdentifierType, value: ValueType) => void;

/**
 * React Kernel global context.
 */
export declare const KernelGlobalContext: default_2.Context<KernelGlobalContextData>;

/**
 * Kernel global context data.
 */
export declare interface KernelGlobalContextData {
    contexts: KernelContexts;
    setContext: KernelContextSetter;
}

/**
 * Kernel global context provider.
 */
export declare function KernelGlobalContextProvider({ children }: default_2.PropsWithChildren<{}>): default_2.JSX.Element;

export declare function ListLoader({ count, itemContent }: {
    /**
     * Sample items count.
     * 3 by default.
     */
    count?: number;
    /**
     * Sample items content or content generator function.
     */
    itemContent?: default_2.ReactNode | ((key: number) => default_2.ReactNode);
}): default_2.JSX.Element;

/**
 * Main component of a main menu.
 */
export declare function MainMenu({ children, className, ...props }: default_2.PropsWithChildren<default_2.HTMLAttributes<HTMLDivElement>>): default_2.JSX.Element;

/**
 * Main component of a main menu item.
 */
export declare const MainMenuItem: default_2.ForwardRefExoticComponent<Omit<default_2.AnchorHTMLAttributes<HTMLAnchorElement>, never> & {
    children?: default_2.ReactNode | undefined;
} & default_2.RefAttributes<HTMLAnchorElement>>;

/**
 * Main menu item properties.
 */
export declare type MainMenuItemProperties = default_2.PropsWithChildren<Modify<default_2.AnchorHTMLAttributes<HTMLAnchorElement>, {}>>;

/**
 * A main menu item that open a submenu.
 */
export declare function MainMenuItemSubmenu({ submenu, className, children, ...props }: Modify<MainMenuItemProperties, {
    /**
     * The submenu content.
     */
    submenu: default_2.ReactNode;
}>): default_2.JSX.Element;

/**
 * A main menu item link.
 */
export declare const MainMenuLink: default_2.ForwardRefExoticComponent<Omit<NavLinkProps & default_2.AnchorHTMLAttributes<HTMLAnchorElement>, never> & {
    children?: default_2.ReactNode | undefined;
} & default_2.RefAttributes<HTMLAnchorElement>>;

/**
 * A main menu item link properties.
 */
export declare type MainMenuLinkProperties = default_2.PropsWithChildren<Modify<NavLinkProps & default_2.AnchorHTMLAttributes<HTMLAnchorElement>, {}>>;

/**
 * Fully managed floating content function.
 */
export declare type Managed<T = default_2.ReactElement | default_2.ReactNode> = (show: () => void, hide: () => void) => T;

/**
 * Modal main component.
 */
export declare function Modal({ className, title, closable, type, children, ...props }: default_2.PropsWithChildren<Modify<default_2.HTMLAttributes<HTMLDivElement>, {
    /**
     * Modal title.
     */
    title?: string;
    /**
     * Can disable close button.
     */
    closable?: boolean;
    /**
     * Modal type. None by default.
     */
    type?: ModalType;
}>>): default_2.JSX.Element;

/**
 * Modal types enumeration.
 */
export declare enum ModalType {
    INFO = "info",
    SUCCESS = "success",
    WARNING = "warning",
    ERROR = "error",
    NONE = "none"
}

/**
 * Icon for each modal type.
 */
export declare const ModalTypeIcon: Record<ModalType, default_2.ReactElement>;

export declare type Modify<T, R> = Omit<T, keyof R> & R;

/**
 * Normalize a given string for searching.
 * @param str The string to normalize.
 */
export declare function normalizeString(str: string): string;

/**
 * Notification component.
 */
declare function Notification_2({ type, children }: default_2.PropsWithChildren<{
    type?: NotificationType;
}>): default_2.JSX.Element;
export { Notification_2 as Notification }

/**
 * A notification context.
 */
export declare const NotificationContext: default_2.Context<{
    /**
     * Notification UUID.
     */
    uuid: NotificationUuid;
    /**
     * Notification closed state.
     */
    closed: boolean;
}>;

/**
 * Notification data.
 */
export declare interface NotificationData {
    /**
     * The notification content.
     */
    content: default_2.ReactNode;
}

export declare const NotificationsContext: default_2.Context<NotificationsContextState>;

/**
 * Interface of notifications state.
 */
export declare interface NotificationsContextState {
    /**
     * Notification function.
     * @param content Notification content.
     */
    notify: EmitNotificationFunction;
    /**
     * Close notification function.
     * @param uuid UUID of notification to close.
     */
    close: CloseNotificationFunction;
    /**
     * Is given notification closed?
     * @param uuid UUID of notification to get closed state.
     */
    isClosed: IsNotificationClosedFunction;
}

/**
 * Notifications provider.
 */
export declare function NotificationsProvider({ children }: default_2.PropsWithChildren<{}>): default_2.JSX.Element;

/**
 * Notifications types enumeration.
 */
export declare enum NotificationType {
    NONE = "none",
    INFO = "info",
    SUCCESS = "success",
    WARNING = "warning",
    ERROR = "error"
}

/**
 * Notification UUID type.
 */
export declare type NotificationUuid = string;

/**
 * A React error boundary that show errors in notifications.
 */
export declare function NotifyErrorsBoundary({ children, onError, fallback, fallbackRender, FallbackComponent, ...props }: default_2.PropsWithChildren<Partial<ErrorBoundaryProps>>): default_2.JSX.Element;

/**
 * The function that opens a curtain.
 */
export declare type OpenCurtainFunction = (content: default_2.ReactNode) => CurtainUuidType;

export declare function OptionsSuggestions<OptionKey extends keyof any, Option>({ options, onSelected, selectedOptions, renderOption, navigator }: {
    /**
     * Options to suggest.
     */
    options: Record<OptionKey, Option>;
    /**
     * Called when an option is selected.
     * @param key
     * @param option
     */
    onSelected: (key: OptionKey, option: Option) => void;
    /**
     * Already selected options that will be shown differently.
     */
    selectedOptions?: Record<OptionKey, Option>;
    /**
     * Render an option.
     * @param option The option to render.
     */
    renderOption?: (option: Option) => default_2.ReactNode;
    /**
     * A reference to a preselected suggestions options navigation object.
     */
    navigator?: MutableRefObject<SuggestionsNavigation>;
}): default_2.ReactNode;

/**
 * Paginated content component with custom page handling.
 */
export declare function Paginate({ page, onChange, count, children }: default_2.PropsWithChildren<{
    /**
     * The current page.
     */
    page: number;
    /**
     * Called when a new page is selected.
     * @param newPage The newly selected page.
     */
    onChange: (newPage: number) => void;
    /**
     * Pages count.
     */
    count: number;
}>): default_2.JSX.Element;

/**
 * Pagination component.
 */
export declare function Pagination({ page, onChange, count }: {
    /**
     * The current page.
     */
    page: number;
    /**
     * Called when a new page is selected.
     * @param newPage The newly selected page.
     */
    onChange: (newPage: number) => void;
    /**
     * Pages count.
     */
    count: number;
}): default_2.JSX.Element;

export declare function PasswordInput({ children, className, type, ...props }: default_2.PropsWithChildren<default_2.InputHTMLAttributes<HTMLInputElement>>): default_2.ReactElement;

/**
 * A type that can be returned by a promise or as is.
 */
export declare type Promisable<T> = T | Promise<T>;

/**
 * A promise production function.
 */
export declare type PromiseFn<T> = () => Promise<T>;

export declare function Radio({ children, className, type, ...inputProps }: default_2.PropsWithChildren<default_2.InputHTMLAttributes<HTMLInputElement>>): default_2.ReactElement;

/**
 * Type of notification close function.
 */
export declare type RemoveNotificationFunction = (uuid: NotificationUuid) => void;

export declare function RequiredField({ className, ...props }: default_2.HTMLAttributes<HTMLSpanElement>): default_2.ReactElement;

/**
 * Generic select component.
 */
export declare function Select<OptionKey extends keyof any, Option>({ className, value, onChange, options, renderOption, match, required, selectibleMinCount, selectibleMaxCount, multiple, blurOnSelect, blurWhenMaxCountSelected, onKeyDown, type, role, children, ...props }: SelectProperties<OptionKey, Option>): default_2.ReactElement;

/**
 * Generic select component properties.
 */
export declare type SelectProperties<OptionKey extends keyof any, Option> = default_2.PropsWithChildren<Modify<default_2.InputHTMLAttributes<HTMLInputElement>, {
    /**
     * The currently selected option(s).
     */
    value: OptionKey | OptionKey[];
    /**
     * Called when new options are selected.
     * @param newValue
     */
    onChange: (newValue: OptionKey | OptionKey[]) => void;
    /**
     * Options list or a way to get it from a given search.
     */
    options: Record<OptionKey, Option>;
    /**
     * Render an option.
     * @param option The option to render.
     */
    renderOption?: (option: Option) => default_2.ReactNode;
    /**
     * Option match function. Return true if the given option matches the given search query.
     * @param search The search query.
     * @param option The option that should match the search query.
     */
    match?: (search: string, option: Option) => boolean;
    /**
     * Min count of options to allow to select.
     * 0 by default, 1 when required is true.
     */
    selectibleMinCount?: number;
    /**
     * Max count of options to allow to select.
     * 1 by default when multiple is false, infinity when multiple is true.
     */
    selectibleMaxCount?: number;
    /**
     * True to allow to select an infinite count of options.
     * false by default.
     */
    multiple?: boolean;
    /**
     * When true, the select loses focus when a new option is selected (by clicking or pressing Enter).
     * false by default.
     */
    blurOnSelect?: boolean;
    /**
     * When true, the select loses focus when the max count of selectible options have been reached (by clicking or pressing Enter).
     * true by default.
     */
    blurWhenMaxCountSelected?: boolean;
    type?: never;
    role?: never;
}>>;

export declare function SimpleSuggestions(): default_2.ReactElement;

export declare function SpinningLoader({ inline }: {
    inline?: boolean;
}): default_2.JSX.Element;

/**
 * Component of a step.
 */
export declare function Step({ stepKey, stepTitle, children }: default_2.PropsWithChildren<{
    /**
     * The current step unique key.
     */
    stepKey: StepKeyType;
    /**
     * The step title, to show in the navigator.
     */
    stepTitle?: default_2.ReactNode;
}>): default_2.JSX.Element;

/**
 * Type of step key.
 */
export declare type StepKeyType = string;

/**
 * Main Steps component.
 */
export declare function Steps({ children }: default_2.PropsWithChildren<{}>): default_2.JSX.Element;

/**
 * The steps global state.
 */
export declare const stepsGlobalState: GlobalState<StepsGlobalStateType, StepsGlobalStateReducers>;

/**
 * The steps global state modification functions.
 */
declare class StepsGlobalStateReducers extends GlobalStateReducers<StepsGlobalStateType> {
    /**
     * Register a new step with its step key.
     * @param newStepKey The step key to register.
     */
    registerStep(newStepKey: StepKeyType, newStepTitle?: default_2.ReactNode): void;
    /**
     * Remove an old step with its step key.
     * @param oldStepKey The step key to remove.
     */
    removeStep(oldStepKey: StepKeyType): void;
    /**
     * Set the current step from its key.
     * @param stepKey The step key to set as the current one.
     */
    setCurrentStep(stepKey: StepKeyType): void;
    /**
     * Get the next step key.
     */
    getNextStep(): StepKeyType;
    /**
     * Get the previous step key.
     */
    getPreviousStep(): StepKeyType;
}

/**
 * Steps global state data type.
 */
export declare interface StepsGlobalStateType {
    /**
     * Steps list, by their order of apparition.
     */
    steps: {
        key: StepKeyType;
        title?: default_2.ReactNode;
    }[];
    /**
     * The index of the current step in the steps list.
     */
    currentStepIndex: number;
}

/**
 * Steps navigator
 */
export declare interface StepsNavigator {
    /**
     * Go to the next step.
     */
    next(): void;
    /**
     * Return to the previous step.
     */
    previous(): void;
    /**
     * Go to the given step.
     * @param stepKey The step key to join.
     */
    set(stepKey: StepKeyType): void;
}

/**
 * Steps navigator component.
 */
export declare function StepsNavigatorComponent(): default_2.JSX.Element;

/**
 * Subapp main component.
 */
export declare function Subapp({ className, title, closable, children }: default_2.PropsWithChildren<Modify<default_2.HTMLAttributes<HTMLDivElement>, {
    /**
     * Subapp title.
     */
    title?: string;
    /**
     * Can disable close button.
     */
    closable?: boolean;
}>>): default_2.JSX.Element;

/**
 * Main component of a submenu.
 */
export declare function Submenu({ className, children, ...props }: default_2.PropsWithChildren<default_2.HTMLAttributes<HTMLDivElement>>): default_2.JSX.Element;

/**
 * Add a submenu which opens on click on the child.
 */
export declare function SubmenuFloat({ submenu, className, mode, dismissible, children, content, ...props }: Modify<FloatProperties, {
    /**
     * The submenu content.
     */
    submenu: default_2.ReactNode;
    content?: never;
}>): default_2.JSX.Element;

/**
 * Main component of a submenu item.
 */
export declare const SubmenuItem: default_2.ForwardRefExoticComponent<Omit<default_2.AnchorHTMLAttributes<HTMLAnchorElement>, never> & {
    children?: default_2.ReactNode | undefined;
} & default_2.RefAttributes<HTMLAnchorElement>>;

/**
 * Submenu item properties.
 */
export declare type SubmenuItemProperties = default_2.PropsWithChildren<Modify<default_2.AnchorHTMLAttributes<HTMLAnchorElement>, {}>>;

/**
 * A submenu item that open a submenu.
 */
export declare function SubmenuItemSubmenu({ submenu, className, children, ...props }: Modify<SubmenuItemProperties, {
    /**
     * The submenu content.
     */
    submenu: default_2.ReactNode;
}>): default_2.JSX.Element;

/**
 * A submenu item link.
 */
export declare const SubmenuLink: default_2.ForwardRefExoticComponent<Omit<NavLinkProps & default_2.AnchorHTMLAttributes<HTMLAnchorElement>, never> & {
    children?: default_2.ReactNode | undefined;
} & default_2.RefAttributes<HTMLAnchorElement>>;

/**
 * A submenu item link properties.
 */
export declare type SubmenuLinkProperties = default_2.PropsWithChildren<Modify<NavLinkProps & default_2.AnchorHTMLAttributes<HTMLAnchorElement>, {}>>;

export declare function Suggestible({ className, suggestions, mode, content, role, children, ...props }: Modify<FloatProperties, {
    /**
     * Suggestions element.
     */
    suggestions: default_2.ReactNode;
    content?: never;
    role?: never;
}>): default_2.JSX.Element;

/**
 * Suggestions preselected options navigation configuration.
 */
export declare interface SuggestionsNavigation {
    /**
     * Return true if the preselected options navigation is initialized.
     */
    initialized(): boolean;
    /**
     * Preselect the next option in the suggestions.
     */
    next(): void;
    /**
     * Preselect the previous option in the suggestions.
     */
    previous(): void;
    /**
     * Select the currently preselected option.
     */
    select(): void;
}

export declare function TimepickerInput({ children, className, value, onChange, onKeyUp, onBlur, type, placeholder, ...props }: default_2.PropsWithChildren<Modify<default_2.InputHTMLAttributes<HTMLInputElement>, {
    value?: Date | null;
    onChange: (newDateTime: Date) => void;
    type?: never;
    placeholder?: never;
}>>): default_2.ReactElement;

/**
 * Simple text tip component.
 */
export declare function Tip({ className, children, ...props }: default_2.PropsWithChildren<default_2.HTMLAttributes<HTMLParagraphElement>>): default_2.JSX.Element;

export declare function ToggleSwitch({ children, className, type, ...inputProps }: default_2.PropsWithChildren<default_2.InputHTMLAttributes<HTMLInputElement>>): default_2.ReactElement;

export declare function Tooltip({ children, content }: {
    children: default_2.ReactElement;
    content: default_2.ReactNode;
}): default_2.ReactElement;

/**
 * Get current error from context or router.
 */
export declare function useApplicationError(): Error;

/**
 * React hook for promise result retrieval.
 * @param promise The promise or a function which produces a promise.
 * @param deps When one of the `deps` change, it will wait for the promise again.
 */
export declare function useAsync<T>(promise: Promisable<T> | PromiseFn<T>, deps?: any[]): [AsyncState<T>, default_2.Dispatch<T>];

/**
 * Hook to create a simple curtain.
 * @param curtainElement Content of the curtain to open.
 */
export declare function useCallableCurtain<F extends CallableCurtainElement>(curtainElement: default_2.ReactNode | F): CallableCurtain<F>;

/**
 * More natural name of useCallableCurtain for modals.
 * @see useCallableCurtain
 */
export declare const useCallableModal: typeof useCallableCurtain;

/**
 * More natural name of useCallableCurtain for subapps.
 * @see useCallableCurtain
 */
export declare const useCallableSubapp: typeof useCallableCurtain;

/**
 * Hook of the current step key in a steps component.
 */
export declare function useCurrentStepKey(): StepKeyType;

/**
 * Hook to access current curtain data and functions.
 */
export declare function useCurtain(): CurtainContextState;

/**
 * Hook to interact with curtains (open or close).
 */
export declare function useCurtains(): CurtainsContextState;

/**
 * Create a callback for a form submit function that fully overrides default form behavior.
 * @param submitFunction The function to call on form submit.
 * @param dependencies Submit function dependencies.
 */
export declare function useFormSubmit(submitFunction: () => void, dependencies?: DependencyList): default_2.FormEventHandler<HTMLFormElement>;

/**
 * Get the global state and its reducers.
 * @param globalState The global state to get.
 */
export declare function useGlobalState<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): [S, R];

/**
 * Global state Provider hook.
 * @param globalState Global state for which to get the global state Provider.
 */
export declare function useGlobalStateProvider<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): default_2.FunctionComponent<PropsWithChildren<{}>>;

/**
 * Get the reducers of the global state.
 * @param globalState The global state for which to get the reducers.
 */
export declare function useGlobalStateReducers<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): R;

/**
 * Get the global state data.
 * @param globalState The global state for which to get the data.
 */
export declare function useGlobalStateValue<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): S;

/**
 * Initialize or get kernel context with given identifier.
 * @param context Context object.
 */
export declare function useKernelContext<T>(context: KernelContext<T>): [T, KernelContextDispatcher<T>];

/**
 * More natural name of useCurtain for modals.
 * @see useCurtain
 */
export declare const useModal: typeof useCurtain;

/**
 * More natural name of useCurtains for modals.
 * @see useCurtains
 */
export declare const useModals: typeof useCurtains;

/**
 * Hook to emit a notification.
 */
export declare function useNotify(): EmitNotificationFunction;

/**
 * Get the previous value of a given value.
 * @param currentValue The current value.
 */
export declare function usePreviousValue<T>(currentValue: T): T;

/**
 * Hook of the steps' navigator.
 */
export declare function useStepsNavigator(): StepsNavigator;

/**
 * More natural name of useCurtain for subapps.
 * @see useCurtain
 */
export declare const useSubapp: typeof useCurtain;

/**
 * More natural name of useCurtains for subapps.
 * @see useCurtains
 */
export declare const useSubapps: typeof useCurtains;

/**
 * Hook to get the preselected options navigation reference.
 */
export declare function useSuggestionsNavigation(): MutableRefObject<SuggestionsNavigation>;

export { }
